[PATCH] Use the correct format for IPMI messages.

Chris Lumens clumens at redhat.com
Tue Mar 24 20:03:29 UTC 2015


Related: rhbz#782019
Resolves: rhbz#1201174
---
 pyanaconda/iutil.py | 9 +++++----
 1 file changed, 5 insertions(+), 4 deletions(-)

diff --git a/pyanaconda/iutil.py b/pyanaconda/iutil.py
index f096619..6798c41 100644
--- a/pyanaconda/iutil.py
+++ b/pyanaconda/iutil.py
@@ -1204,10 +1204,11 @@ def ipmi_report(event):
 
     # EVM revision - always 0x4
     # Sensor type - always 0x1F for Base OS Boot/Installation Status
-    # Sensor num - passed in event
-    # Event dir & type - always 0x0 for anaconda's purposes
-    # Event data 1, 2, 3 - 0x0 for now
-    eintr_retry_call(os.write, fd, "0x4 0x1F %#x 0x0 0x0 0x0 0x0\n" % event)
+    # Sensor num - always 0x0 for us
+    # Event dir & type - always 0x6f for us
+    # Event data 1 - the event code passed in
+    # Event data 2 & 3 - always 0x0 for us
+    eintr_retry_call(os.write, fd, "0x4 0x1F 0x0 0x6f %#x 0x0 0x0\n" % event)
     eintr_retry_call(os.close, fd)
 
     execWithCapture("ipmitool", ["sel", "add", path])
-- 
2.2.2



More information about the anaconda-patches mailing list